@@ -106,9 +106,10 @@ func testRuntimeOptionsCase(t *testing.T, tc runtimeOptionsTestCase) {
 func TestRuntimeOptions(t *testing.T) {
 	t.Parallel()
 	var (
-		defaultCompatMode  = null.NewString("extended", false)
-		baseCompatMode     = null.NewString("base", true)
-		extendedCompatMode = null.NewString("extended", true)
+		defaultCompatMode   = null.NewString("extended", false)
+		baseCompatMode      = null.NewString("base", true)
+		extendedCompatMode  = null.NewString("extended", true)
+		defaultTracesOutput = null.NewString("none", false)
 	)
 
 	runtimeOptionsTestCases := map[string]runtimeOptionsTestCase{
@@ -119,6 +120,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(true, false),
 				CompatibilityMode:    defaultCompatMode,
 				Env:                  nil,
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"disabled sys env by default": {
@@ -128,6 +130,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(false, false),
 				CompatibilityMode:    defaultCompatMode,
 				Env:                  map[string]string{},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"disabled sys env by default with ext compat mode": {
@@ -137,6 +140,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(false, false),
 				CompatibilityMode:    extendedCompatMode,
 				Env:                  map[string]string{},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"disabled sys env by cli 1": {
@@ -147,6 +151,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(false, true),
 				CompatibilityMode:    baseCompatMode,
 				Env:                  map[string]string{},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"disabled sys env by cli 2": {
@@ -157,6 +162,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(false, true),
 				CompatibilityMode:    baseCompatMode,
 				Env:                  map[string]string{},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"disabled sys env by env": {
@@ -166,6 +172,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(false, true),
 				CompatibilityMode:    extendedCompatMode,
 				Env:                  map[string]string{},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"enabled sys env by env": {
@@ -175,6 +182,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(true, true),
 				CompatibilityMode:    extendedCompatMode,
 				Env:                  map[string]string{"K6_INCLUDE_SYSTEM_ENV_VARS": "true", "K6_COMPATIBILITY_MODE": "extended"},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"enabled sys env by default": {
@@ -185,6 +193,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(true, false),
 				CompatibilityMode:    defaultCompatMode,
 				Env:                  map[string]string{"test1": "val1"},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"enabled sys env by cli 1": {
@@ -195,6 +204,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(true, true),
 				CompatibilityMode:    defaultCompatMode,
 				Env:                  map[string]string{"test1": "val1"},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"enabled sys env by cli 2": {
@@ -205,6 +215,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(true, true),
 				CompatibilityMode:    defaultCompatMode,
 				Env:                  map[string]string{"test1": "val1"},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"run only system env": {
@@ -215,6 +226,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(true, false),
 				CompatibilityMode:    defaultCompatMode,
 				Env:                  map[string]string{"test1": "val1"},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"mixed system and cli env": {
@@ -225,6 +237,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(true, false),
 				CompatibilityMode:    defaultCompatMode,
 				Env:                  map[string]string{"test1": "val1", "test2": "", "test3": "val3", "test4": "", "test5": ""},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"mixed system and cli env 2": {
@@ -235,6 +248,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(true, true),
 				CompatibilityMode:    defaultCompatMode,
 				Env:                  map[string]string{"test1": "val1", "test2": "", "test3": "val3", "test4": "", "test5": ""},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"disabled system env with cli params": {
@@ -245,6 +259,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(false, false),
 				CompatibilityMode:    defaultCompatMode,
 				Env:                  map[string]string{"test2": "val2"},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"overwriting system env with cli param": {
@@ -255,6 +270,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(true, false),
 				CompatibilityMode:    defaultCompatMode,
 				Env:                  map[string]string{"test1": "val1cli"},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"error wrong compat mode env var value": {
@@ -296,6 +312,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(true, false),
 				CompatibilityMode:    defaultCompatMode,
 				Env:                  map[string]string{"test1": "value 1", "test2": "value 2"},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"valid env vars with special chars": {
@@ -306,6 +323,7 @@ func TestRuntimeOptions(t *testing.T) {
 				IncludeSystemEnvVars: null.NewBool(true, false),
 				CompatibilityMode:    defaultCompatMode,
 				Env:                  map[string]string{"test1": "value 1", "test2": "value,2", "test3": ` ,  ,,, value, ,, 2!'@#,"`},
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"summary and thresholds from env": {
@@ -318,6 +336,7 @@ func TestRuntimeOptions(t *testing.T) {
 				NoThresholds:         null.NewBool(false, true),
 				NoSummary:            null.NewBool(false, true),
 				SummaryExport:        null.NewString("foo", true),
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"summary and thresholds from env overwritten by CLI": {
@@ -331,6 +350,7 @@ func TestRuntimeOptions(t *testing.T) {
 				NoThresholds:         null.NewBool(true, true),
 				NoSummary:            null.NewBool(true, true),
 				SummaryExport:        null.NewString("bar", true),
+				TracesOutput:         defaultTracesOutput,
 			},
 		},
 		"env var error detected even when CLI flags overwrite 1": {
@@ -345,6 +365,36 @@ func TestRuntimeOptions(t *testing.T) {
 			cliFlags:  []string{"--no-summary", "true"},
 			expErr:    true,
 		},
+		"traces output default": {
+			useSysEnv: false,
+			expRTOpts: lib.RuntimeOptions{
+				IncludeSystemEnvVars: null.NewBool(false, false),
+				CompatibilityMode:    defaultCompatMode,
+				Env:                  map[string]string{},
+				TracesOutput:         null.NewString("none", false),
+			},
+		},
+		"traces output from env": {
+			useSysEnv: false,
+			systemEnv: map[string]string{"K6_TRACES_OUTPUT": "foo"},
+			expRTOpts: lib.RuntimeOptions{
+				IncludeSystemEnvVars: null.NewBool(false, false),
+				CompatibilityMode:    defaultCompatMode,
+				Env:                  map[string]string{},
+				TracesOutput:         null.NewString("foo", true),
+			},
+		},
+		"traces output from env overwritten by CLI": {
+			useSysEnv: false,
+			systemEnv: map[string]string{"K6_TRACES_OUTPUT": "foo"},
+			cliFlags:  []string{"--traces-output", "bar"},
+			expRTOpts: lib.RuntimeOptions{
+				IncludeSystemEnvVars: null.NewBool(false, false),
+				CompatibilityMode:    defaultCompatMode,
+				Env:                  map[string]string{},
+				TracesOutput:         null.NewString("bar", true),
+			},
+		},
 	}
 	for name, tc := range runtimeOptionsTestCases {
 		tc := tc
