@@ -5,6 +5,7 @@ import (
 
 	"github.com/sirupsen/logrus"
 	"go.k6.io/k6/event"
+	"go.k6.io/k6/lib/trace"
 	"go.k6.io/k6/metrics"
 )
 
@@ -18,6 +19,7 @@ type TestPreInitState struct {
 	KeyLogger      io.Writer
 	LookupEnv      func(key string) (val string, ok bool)
 	Logger         logrus.FieldLogger
+	TracerProvider *trace.TracerProvider
 }
 
 // TestRunState contains the pre-init state as well as all of the state and
