@@ -2,7 +2,7 @@ package loader
 
 import "github.com/sirupsen/logrus"
 
-func github(_ logrus.FieldLogger, path string, parts []string) (string, error) {
+func github(_ logrus.FieldLogger, _ string, parts []string) (string, error) {
 	username := parts[0]
 	repo := parts[1]
 	filepath := parts[2]
