@@ -49,7 +49,7 @@ const (
 		`local directory (-v /local/path/:/inside/docker/path) containing ` +
 		`your script and modules so that they're accessible by k6 from ` +
 		`inside of the container, see ` +
-		`https://k6.io/docs/using-k6/modules#using-local-modules-with-docker.`
+		`https://grafana.com/docs/k6/latest/using-k6/modules/#using-local-modules-with-docker.`
 )
 
 type unresolvableURLError string
