@@ -7,20 +7,25 @@ import (
 	"errors"
 	"fmt"
 	"net/http"
+	"strconv"
 	"sync"
 	"time"
 
 	"go.k6.io/k6/cloudapi"
+	"go.k6.io/k6/cloudapi/insights"
 	"go.k6.io/k6/errext"
 	"go.k6.io/k6/errext/exitcodes"
+	"go.k6.io/k6/lib/consts"
 	"go.k6.io/k6/metrics"
 	"go.k6.io/k6/output"
+	insightsOutput "go.k6.io/k6/output/cloud/insights"
 
 	"github.com/sirupsen/logrus"
 )
 
+// flusher is an interface for flushing data to the cloud.
 type flusher interface {
-	flush(context.Context) error
+	flush() error
 }
 
 // Output sends result data to the k6 Cloud service.
@@ -30,11 +35,15 @@ type Output struct {
 	logger      logrus.FieldLogger
 	config      cloudapi.Config
 	cloudClient *cloudapi.Client
-	referenceID string
+	testRunID   string
 
 	collector *collector
 	flushing  flusher
 
+	insightsClient            insightsOutput.Client
+	requestMetadatasCollector insightsOutput.RequestMetadatasCollector
+	requestMetadatasFlusher   insightsOutput.RequestMetadatasFlusher
+
 	// wg tracks background goroutines
 	wg sync.WaitGroup
 
@@ -48,19 +57,26 @@ type Output struct {
 }
 
 // New creates a new cloud output.
-func New(logger logrus.FieldLogger, conf cloudapi.Config, cloudClient *cloudapi.Client) (*Output, error) {
+func New(logger logrus.FieldLogger, conf cloudapi.Config, _ *cloudapi.Client) (*Output, error) {
 	return &Output{
-		config:      conf,
-		logger:      logger.WithField("output", "cloudv2"),
-		cloudClient: cloudClient,
-		abort:       make(chan struct{}),
-		stop:        make(chan struct{}),
+		config: conf,
+		logger: logger.WithField("output", "cloudv2"),
+		abort:  make(chan struct{}),
+		stop:   make(chan struct{}),
+
+		// TODO: move this creation operation to the centralized output. Reducing the probability to
+		// break the logic for the config overwriting.
+		//
+		// It creates a new client because in the case the backend has overwritten
+		// the config we need to use the new set.
+		cloudClient: cloudapi.NewClient(
+			logger, conf.Token.String, conf.Host.String, consts.Version, conf.Timeout.TimeDuration()),
 	}, nil
 }
 
-// SetReferenceID sets the Cloud's test run ID.
-func (o *Output) SetReferenceID(refID string) {
-	o.referenceID = refID
+// SetTestRunID sets the Cloud's test run id.
+func (o *Output) SetTestRunID(id string) {
+	o.testRunID = id
 }
 
 // SetTestRunStopCallback receives the function that
@@ -74,6 +90,7 @@ func (o *Output) SetTestRunStopCallback(stopFunc func(error)) {
 // for metric samples and send them to the cloud.
 func (o *Output) Start() error {
 	o.logger.Debug("Starting...")
+	defer o.logger.Debug("Started!")
 
 	var err error
 	o.collector, err = newCollector(
@@ -83,29 +100,56 @@ func (o *Output) Start() error {
 		return fmt.Errorf("failed to initialize the samples collector: %w", err)
 	}
 
-	mc, err := newMetricsClient(o.cloudClient)
+	mc, err := newMetricsClient(o.cloudClient, o.testRunID)
 	if err != nil {
 		return fmt.Errorf("failed to initialize the http metrics flush client: %w", err)
 	}
 	o.flushing = &metricsFlusher{
-		referenceID:                o.referenceID,
+		testRunID:                  o.testRunID,
 		bq:                         &o.collector.bq,
 		client:                     mc,
+		logger:                     o.logger,
+		discardedLabels:            make(map[string]struct{}),
 		aggregationPeriodInSeconds: uint32(o.config.AggregationPeriod.TimeDuration().Seconds()),
-		// TODO: rename the config field to align to the new logic by time series
-		// when the migration from the version 1 is completed.
-		maxSeriesInSingleBatch: int(o.config.MaxMetricSamplesPerPackage.Int64),
+		maxSeriesInBatch:           int(o.config.MaxTimeSeriesInBatch.Int64),
+		// TODO: when the migration from v1 is over
+		// change the default of cloudapi.MetricPushConcurrency to use GOMAXPROCS(0)
+		batchPushConcurrency: int(o.config.MetricPushConcurrency.Int64),
 	}
 
-	o.runFlushWorkers()
+	o.runPeriodicFlush()
 	o.periodicInvoke(o.config.AggregationPeriod.TimeDuration(), o.collectSamples)
 
+	if insightsOutput.Enabled(o.config) {
+		testRunID, err := strconv.ParseInt(o.testRunID, 10, 64)
+		if err != nil {
+			return err
+		}
+		o.requestMetadatasCollector = insightsOutput.NewCollector(testRunID)
+
+		insightsClientConfig := insights.NewDefaultClientConfigForTestRun(
+			o.config.TracesHost.String,
+			o.config.Token.String,
+			testRunID,
+		)
+		insightsClient := insights.NewClient(insightsClientConfig)
+
+		if err := insightsClient.Dial(context.Background()); err != nil {
+			return err
+		}
+
+		o.insightsClient = insightsClient
+		o.requestMetadatasFlusher = insightsOutput.NewFlusher(insightsClient, o.requestMetadatasCollector)
+		o.runFlushRequestMetadatas()
+	}
+
 	o.logger.WithField("config", printableConfig(o.config)).Debug("Started!")
+
 	return nil
 }
 
 // StopWithTestError gracefully stops all metric emission from the output.
-func (o *Output) StopWithTestError(testErr error) error {
+func (o *Output) StopWithTestError(_ error) error {
 	o.logger.Debug("Stopping...")
 	defer o.logger.Debug("Stopped!")
 
@@ -125,32 +169,39 @@ func (o *Output) StopWithTestError(testErr error) error {
 	o.collectSamples()
 	o.flushMetrics()
 
+	// Flush all the remaining request metadatas.
+	if insightsOutput.Enabled(o.config) {
+		o.flushRequestMetadatas()
+		if err := o.insightsClient.Close(); err != nil {
+			o.logger.WithError(err).Error("Failed to close the insights client")
+		}
+	}
+
 	return nil
 }
 
-func (o *Output) runFlushWorkers() {
+func (o *Output) runPeriodicFlush() {
 	t := time.NewTicker(o.config.MetricPushInterval.TimeDuration())
 
-	for i := int64(0); i < o.config.MetricPushConcurrency.Int64; i++ {
-		o.wg.Add(1)
-		go func() {
-			defer func() {
-				t.Stop()
-				o.wg.Done()
-			}()
+	o.wg.Add(1)
 
-			for {
-				select {
-				case <-t.C:
-					o.flushMetrics()
-				case <-o.stop:
-					return
-				case <-o.abort:
-					return
-				}
-			}
+	go func() {
+		defer func() {
+			t.Stop()
+			o.wg.Done()
 		}()
-	}
+
+		for {
+			select {
+			case <-t.C:
+				o.flushMetrics()
+			case <-o.stop:
+				return
+			case <-o.abort:
+				return
+			}
+		}
+	}()
 }
 
 // AddMetricSamples receives the samples streaming.
@@ -201,15 +252,16 @@ func (o *Output) collectSamples() {
 	samples := o.GetBufferedSamples()
 	o.collector.CollectSamples(samples)
 
-	// TODO: other operations with the samples containers
-	// e.g. flushing the Metadata as tracing samples
+	if insightsOutput.Enabled(o.config) {
+		o.requestMetadatasCollector.CollectRequestMetadatas(samples)
+	}
 }
 
 // flushMetrics receives a set of metric samples.
 func (o *Output) flushMetrics() {
 	start := time.Now()
 
-	err := o.flushing.flush(context.Background())
+	err := o.flushing.flush()
 	if err != nil {
 		o.handleFlushError(err)
 		return
@@ -218,6 +270,43 @@ func (o *Output) flushMetrics() {
 	o.logger.WithField("t", time.Since(start)).Debug("Successfully flushed buffered samples to the cloud")
 }
 
+func (o *Output) runFlushRequestMetadatas() {
+	t := time.NewTicker(o.config.TracesPushInterval.TimeDuration())
+
+	for i := int64(0); i < o.config.TracesPushConcurrency.Int64; i++ {
+		o.wg.Add(1)
+		go func() {
+			defer o.wg.Done()
+			defer t.Stop()
+
+			for {
+				select {
+				case <-t.C:
+					o.flushRequestMetadatas()
+				case <-o.stop:
+					return
+				case <-o.abort:
+					return
+				}
+			}
+		}()
+	}
+}
+
+// flushRequestMetadatas periodically flushes traces collected in RequestMetadatasCollector using flusher.
+func (o *Output) flushRequestMetadatas() {
+	start := time.Now()
+
+	err := o.requestMetadatasFlusher.Flush()
+	if err != nil {
+		o.logger.WithError(err).WithField("t", time.Since(start)).Error("Failed to push trace samples to the cloud")
+
+		return
+	}
+
+	o.logger.WithField("t", time.Since(start)).Debug("Successfully flushed buffered trace samples to the cloud")
+}
+
 // handleFlushError handles errors generated from the flushing operation.
 // It may interrupt the metric collection or invoke aborting of the test.
 //
@@ -227,24 +316,30 @@ func (o *Output) flushMetrics() {
 // Instead, if cloudapi.Config.StopOnError is enabled the cloud output should
 // stop the whole test run too. This logic should be handled by the caller.
 func (o *Output) handleFlushError(err error) {
+	// Don't actually handle any errors if we were aborted
+	select {
+	case <-o.abort:
+		return
+	default:
+	}
+
 	o.logger.WithError(err).Error("Failed to push metrics to the cloud")
 
 	var errResp cloudapi.ErrorResponse
 	if !errors.As(err, &errResp) || errResp.Response == nil {
 		return
 	}
-
 	// The Cloud service returns the error code 4 when it doesn't accept any more metrics.
 	// So, when k6 sees that, the cloud output just stops prematurely.
 	if errResp.Response.StatusCode != http.StatusForbidden || errResp.Code != 4 {
 		return
 	}
 
-	o.logger.WithError(err).Warn("Interrupt sending metrics to cloud due to an error")
-
 	// Do not close multiple times (that would panic) in the case
 	// we hit this multiple times and/or concurrently
 	o.abortOnce.Do(func() {
+		o.logger.WithError(err).Warn("Interrupt sending metrics to cloud due to an error")
+
 		close(o.abort)
 
 		if o.config.StopOnError.Bool {
@@ -262,20 +357,20 @@ func (o *Output) handleFlushError(err error) {
 
 func printableConfig(c cloudapi.Config) map[string]any {
 	m := map[string]any{
-		"host":                       c.Host.String,
-		"name":                       c.Name.String,
-		"timeout":                    c.Timeout.String(),
-		"webAppURL":                  c.WebAppURL.String,
-		"projectID":                  c.ProjectID.Int64,
-		"pushRefID":                  c.PushRefID.String,
-		"stopOnError":                c.StopOnError.Bool,
-		"testRunDetails":             c.TestRunDetails.String,
-		"aggregationPeriod":          c.AggregationPeriod.String(),
-		"aggregationWaitPeriod":      c.AggregationWaitPeriod.String(),
-		"maxMetricSamplesPerPackage": c.MaxMetricSamplesPerPackage.Int64,
-		"metricPushConcurrency":      c.MetricPushConcurrency.Int64,
-		"metricPushInterval":         c.MetricPushInterval.String(),
-		"token":                      "",
+		"host":                  c.Host.String,
+		"name":                  c.Name.String,
+		"timeout":               c.Timeout.String(),
+		"webAppURL":             c.WebAppURL.String,
+		"projectID":             c.ProjectID.Int64,
+		"pushRefID":             c.PushRefID.String,
+		"stopOnError":           c.StopOnError.Bool,
+		"testRunDetails":        c.TestRunDetails.String,
+		"aggregationPeriod":     c.AggregationPeriod.String(),
+		"aggregationWaitPeriod": c.AggregationWaitPeriod.String(),
+		"maxTimeSeriesInBatch":  c.MaxTimeSeriesInBatch.Int64,
+		"metricPushConcurrency": c.MetricPushConcurrency.Int64,
+		"metricPushInterval":    c.MetricPushInterval.String(),
+		"token":                 "",
 	}
 
 	if c.Token.Valid {
